@@ -23,11 +23,25 @@
 
 #include "seahorse-gkr-module.h"
 
-#include "seahorse-gkr-commands.h"
-#include "seahorse-gkeyring-source.h"
+#include "seahorse-gkr-dialogs.h"
+#include "seahorse-gkr-item-commands.h"
+#include "seahorse-gkr-keyring-commands.h"
+#include "seahorse-gkr-source.h"
 
-const SeahorseRegisterType SEAHORSE_GKR_REGISTRY[] = {
-	seahorse_gkeyring_source_get_type,
-	seahorse_gkeyring_commands_get_type,
-	NULL
-};
+#include "seahorse-context.h"
+
+#include <gnome-keyring.h>
+
+void
+seahorse_gkr_module_init (void)
+{
+	SeahorseSource *source;
+
+	source = SEAHORSE_SOURCE (seahorse_gkr_source_new ());
+	seahorse_context_take_source (NULL, source);
+	
+	/* Let these classes register themselves */
+	g_type_class_unref (g_type_class_ref (SEAHORSE_TYPE_GKR_SOURCE));
+	g_type_class_unref (g_type_class_ref (SEAHORSE_TYPE_GKR_ITEM_COMMANDS));
+	g_type_class_unref (g_type_class_ref (SEAHORSE_TYPE_GKR_KEYRING_COMMANDS));
+}
